Update hipMathFunctions, hipTestHalf and hipTestNativeHalf tests to support Navi10 and Navi14. (#1545)

[ROCm/hip commit: 2fb734ef5f]
Tá an tiomantas seo le fáil i:
vsytch
2019-10-16 01:21:48 -04:00
tiomanta ag Maneesh Gupta
tuismitheoir cba73a44ef
tiomantas eaa616bf6d
D'athraigh 3 comhad le 18 breiseanna agus 3 scriosta
@@ -29,7 +29,12 @@ THE SOFTWARE.
#include "hip/hip_runtime.h"
#include "test_common.h"
#if __HIP_ARCH_GFX803__ || __HIP_ARCH_GFX900__ || __HIP_ARCH_GFX906__ || __HIP_ARCH_GFX908__
#if __HIP_ARCH_GFX803__ || \
__HIP_ARCH_GFX900__ || \
__HIP_ARCH_GFX906__ || \
__HIP_ARCH_GFX908__ || \
__HIP_ARCH_GFX1010__ || \
__HIP_ARCH_GFX1012__
__global__ void kernel_abs_int64(long long *input, long long *output) {
int tx = threadIdx.x;